param(
     [Parameter()]
     [string]$spacename,

     [Parameter()]
     [string]$filename
 )

 #call from Qlik Sense Client-Managed using external tasks in QMC
 #example:
 #path >> c:\windows\system32\windowspowershell\v1.0\powershell.exe
 #parameters >> -File "C:\Users\Qlik\Desktop\QlikMigrationPlaybook\uploadqlikclouddata.ps1" myspacename "C:\Users\Qlik\Desktop\QlikMigrationPlaybook\testing3.txt"

#set the working directory for the Migration Playbook
cd "C:\Users\Qlik\Desktop\QlikMigrationPlaybook"

$ts = Get-Date -Format "yyyy_MM_dd_HH_mm_ss"
Start-Transcript -Path ".\Logs\uploadfile_$ts.txt"

. .\0_globals.ps1

.\qlik context use $QlikSaaSContext

$spaceId = .\qlik space filter --names $spacename -q
$connectionId = .\qlik data-file connection ls --spaceId $spaceId -q
Write-Host "spacename: $spacename, spaceid: $spaceId, connectionId: $connectionId"

$name = Split-Path $filename -Leaf

#check if exists
$fileid = .\qlik data-file ls --connectionId $connectionId --name $name -q
Write-Host "fileid: $fileid"
if($fileid)
{
    Write-Host "Updating File"
    .\qlik data-file update $fileid --file $filename --name $name --connectionId $connectionId
}
else
{
    Write-Host "New File"
    .\qlik data-file create --file $filename --name $name --connectionId $connectionId --json
}

$ret = $LASTEXITCODE
Write-Host "Exit Code: $ret"
if($ret -gt 0)
{
    $ret = 8
}

Stop-Transcript

exit $ret
